(function(fn) {
	if (!window.fpFileProc) {
		window.fpFileProc = new fn();
	}
})(function() {
	function FileProc() {
		var isJR = false;
	};
	
	FileProc.prototype = {
		openFile : function(file, filePath) {
			this.isJR = true;
			if(!WebPDF.Engine){
				WebPDF.Engine = {};
			}
			WebPDF.Engine.isJR = true;
			WebPDF.Engine.JR = true;

			var readerApp = WebPDF.Tool.getReaderApp();
			readerApp.setCurrentDriverName("");
			
			var fileName = getFileName(filePath);
			
			var reader = new FileReader();
			reader.readAsArrayBuffer(file);
			
			return new Promise(function(resolve){
				reader.onload = function(e) {
					var bufarray = new Uint8Array(e.target.result);
					resolve(WebPDF.ViewerInstance.openFileByStream(bufarray, fileName, fileName));
				};
			});
		},
		
		openFileByUri : function() {
			var readerApp = WebPDF.Tool.getReaderApp();
			readerApp.setCurrentDriverName("");
			var openFileUrl = "";
			
	        var objectId = getDocUri();
	        if (objectId) {
	        	readerApp.setObjectId(objectId);
		        readerApp.setCurrentDriverName('FoxitDrive');
		        
		        var token = WebPDF.AccountInstance.getAccessToken();
		        
		        var cloudApiDomain = phantomOnlineGlobalConfig.apiUrl;
		        var url = cloudApiDomain + "api/document/cmis-document?object_id=" + objectId + "&access-token=" + token;
		        $.ajax({
		        	url:url,
		        	method:'GET',
		        	success: function(res) {
		        		if (res.ret == 0) {
		        			var downloadUrl = res.data.download_url;
		        			var cmis_document = res.data.cmis_document;
		        			var acl = cmis_document.acl;
		        			
		        			var docPath = cmis_document.properties["cmis:path"];
                            var indx = docPath.lastIndexOf('\/');
                            docPath = docPath.substring(0, indx);
                            readerApp.setCurrentDriverDocPath(docPath);
                            
                            var fileName = cmis_document.properties["cmis:name"];
                            readerApp.setFileName(fileName);
                            
                            var params = { 
                                url: downloadUrl,
                                fileId: fileName,
                                fileName: fileName                        
                            };
                            WebPDF.ViewerInstance.openFileByUri(params);
		        		}
		        		return;
		        	},
		        	error: function() {
		        		return;
		        	}
		        });
	        }
		},
		
		importFDFFile :  function(file) {
			if (WebPDF.Engine.isJR) {
				var reader = new FileReader();
				reader.readAsArrayBuffer(file);
				
				reader.onload = function(e) {
					var bufarray = e.target.result;
					var paramData = {
						type: 'fileBuffer',
						fileBuffer: bufarray
					};
					WebPDF.ViewerInstance.importAnnotsFromFDF(paramData);
				}
			} else {
				var email = WebPDF.AccountInstance.getUserAccount();
				var url = WebPDF.serverBaseUrl + 'asserts/getAnnotsDataFromFDFFile?email=' + email + '&_='+WebPDF.Common.unique();
				var xhr = new XMLHttpRequest();
				xhr.open('post', url, true);
				
				var fd = new FormData(); 
				fd.append('file', file);
				
				xhr.onload = function (response) {
					WebPDF.closeUploading();
					if (response && response.error == 0) {
						var annotsJsons = String.utf8ArrayToString(response.data);
						var pdfDoc = WebPDF.Tool.getReaderApp().getPDFDoc();
						if (pdfDoc) {
							var jsonAnnotsData = $.parseJSON(annotsJsons);
							pdfDoc.importAnnotsFromJsonData(jsonAnnotsData.annotsArr);
						}
					} else {
						WebPDF.alert(null, null, i18n.t("PCLng.ToolBar.ImportFile.FDFFailed"));
					}
				}
				
				xhr.onerror= function(XmlHttpRequest, textStatus, errorThrown) {
					WebPDF.closeUploading();
					WebPDF.alert(null, null, i18n.t("CommonLng.Create.FailToUpload"));
				}
				
				xhr.upload.onloadstart = function () {
					WebPDF.uploading(null, 0);
				}
				
				xhr.upload.onprogress = function (event, position, total, percentComplete) {
					WebPDF.uploading(null, parseInt(event.loaded / event.total));
				}

				xhr.send(fd);
			}
		},
		
		ImportXFDFFileToPDF : function(file) {
			var blobSlice = File.prototype.slice || File.prototype.mozSlice || File.prototype.webkitSlice,
			chunkSize = 1048576, // Read in chunks of 1MB
			currentChunk = 0,
			fileReader = new FileReader(),
			fileSize = file.size;
			chunks = Math.ceil(file.size / chunkSize);
			var fileBuffer = new Array();

			fileReader.onload = function(e) {
				fileBuffer.push(e.target.result); // Append array buffer
				currentChunk++;

				if (currentChunk < chunks) {
					loadNextChunk();
				} else {
					//
					var buffer = new Uint8Array(fileBuffer[0]);
					length = buffer.length;
					WebPDF.ViewerInstance.importAnnotsFromXFDF(buffer);

				}
			};

			fileReader.onerror = function() {
				console.warn('oops, something went wrong.');
			};

			function loadNextChunk() {
				var start = currentChunk * chunkSize,
				end = ((start + chunkSize) >= file.size) ? file.size : start + chunkSize;
				fileReader.readAsArrayBuffer(blobSlice.call(file, start, end));
			}

			loadNextChunk();
		},
		
		importFormXML : function(file) {
			if (WebPDF.Engine.isJR) {
				var fileReader = new FileReader();
				fileReader.readAsArrayBuffer(file);
				fileReader.onload = function(e) {
					var xmlData = String.fromCharCode.apply(null, new Uint8Array(e.target.result));
					xmlData = decodeURIComponent(escape(xmlData))
					xmlData = $.parseXML(xmlData);
					var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
					if (formPlugin) {
						formPlugin.importFromXML(xmlData);
					}
				};
			} else {
				var email = WebPDF.AccountInstance.getUserAccount();
				var importFormXMLURL = WebPDF.serverBaseUrl + 'form/xml/importXml?email=' + email;
				$.ajax({
					type: 'post',
					dataType: "xml",
					url: importFormXMLURL,
					crossdomain: true,
					success: function(data) {
						var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
						if (formPlugin) {
							formPlugin.importFromXML(data);
						}
					},
					error: function(XmlHttpRequest, textStatus, errorThrown) {
						WebPDF.alert(null, null, "import xml file error");
					}
				});
			}
		}
	};
	
	return FileProc;
}());
