(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (factory((global.toolbarConfig = {})));
}(this, (function (exports) { 'use strict';

    var topToolbar = {
        type: 'panel',
        layout: 'flow',
        gap: 'md',
        cls: 'mobile__top-toolbar',
        sub: [{
            type: 'togglebutton',
            cls: 'file-menu-btn',
            iconCls: 'mobile__icon-sidebar',
            toggle: 'filemenu'
        }, {
            type: 'button',
            iconCls: 'mobile__icon-navigation',
            handler: function(){
                if(WebPDF.NavigationComponent) {
                    WebPDF.NavigationComponent.toggle();
                }
            }
        }, {
            type: 'togglebutton',
            cls: 'mobile__toggle-view-btn',
            iconCls: 'mobile__icon-view-tabs',
            name: 'functionalities-toggler',
            toggle: 'functionalities',
            handler: function(){
                if(WebPDF.NavigationComponent) {
                    WebPDF.NavigationComponent.expand(false);
                }
            }
        }, {
            type: 'button',
            iconCls: 'mobile__icon-hand',
            handler: 'switcher',
            ga: {ct: 'Home', ac: 'Hand'},
            params: {
                toolname:'Hand'
            }
        }, {
            type: 'button',
            iconCls: 'mobile__icon-search',
            handler: 'mobile-quick-search',
            action: 'showpanel'
        }, {
            type: 'fileSelector',
            cls: 'hide-on-disabled',
            iconCls: 'mobile__icon-import-form',
            handler: 'importform',
            ga: {ct: 'Home', ac: 'Import Form'},
            accept: ['.xml'],
            permissions: ['form']
        }, {
            type: 'button',
            cls: 'hide-on-disabled',
            iconCls: 'mobile__icon-export-form',
            extend:'exportFormXML',
            handler: 'exportform',
            ga: {ct: 'Home', ac: 'Export Form'},
            permissions: ['form', 'exportform']
        }]
    };

    var undoredoToolbar = {
        type: 'draggablepanel',
        layout: 'flow',
        gap: 'md',
        cls: 'mobile__top-undoredo-toolbar',
        appendTo:'#main-view',
        handler: 'undoRedoContainer',
        sub:[{
            type: 'button',
            iconCls: 'mobile__icon-undo',
            handler: 'undoredo',
            action: 'undo'
        },{
            type: 'button',
            iconCls: 'mobile__icon-redo',
            handler: 'undoredo',
            action: 'redo'
        }]
    };

    var pageOrganizeToolbar = {
        name: 'pageorganizepanel',
        type: 'panel',
        cls: 'mobile_ppo-toptoolbar mobile__top-toggle-toolbar',
        sub: [{
            type: 'button',
            text:'MobileToolbar.PPO.Cancel',
            name: 'cancel-ppo-btn',
            cls: 'button-inline',
            handler: 'mobileppo',
            action: 'cancel'
        }, {
            type: 'plaintext',
            cls: 'mobile_ppo-title',
            text:'Page Organize'
        },{
            type: 'button',
            text: 'MobileToolbar.PPO.Done',
            name: 'save-ppo-btn',
            cls: 'button-inline',
            handler: 'mobileppo',
            action: 'done'
        }]
    };

    var viewTabs = {
        name: 'functionalities',
        type: 'togglepanel',
        cls: 'mobile__tab-panel',
        layout: 'grid',
        gapv: 'md',
        width: '100%',
        cols: 2,
        sub: [{
            type: 'button',
            text: 'MobileToolbar.Tab.View',
            iconCls: 'mobile__icon-tab-view',
            canBeDisabled: false,
            handler: 'mobile-tab',
            params: {
                active: true,
                target: 'viewpanel'
            }
        }, {
            type: 'button',
            text: 'MobileToolbar.Tab.Comment',
            iconCls: 'mobile__icon-tab-comment',
            canBeDisabled: false,
            handler: 'mobile-tab',
            params: {
                target: 'commentpanel'
            }
        }, {
            type: 'button',
            text: 'MobileToolbar.Tab.Edit',
            iconCls: 'mobile__icon-tab-edit',
            canBeDisabled: false,
            handler: 'mobile-tab',
            params: {
                target: 'editpanel'
            }
        }, {
            type: 'button',
            text: 'MobileToolbar.Tab.PPO',
            iconCls: 'mobile__icon-tab-ppo',
            handler: 'mobile-tab',
            params: {
                target: 'pageorganizepanel'
            },
            events: {
                afterhandle: function() {
                    WebPDF.ViewerInstance.changeViewer(WebPDF.VIEWETYPE.ppoViewer);
                    var $ppoTools = $('#ppoTools');
                    if ($ppoTools.find('.mobile_ppo-title').length == 0) {
                        var $title = $('<span class="mobile_ppo-title" data-i18n="Page Organize"></span>');
                        $title.i18n();
                        $ppoTools.append($title);
                    }
                }
            }
        }, {
            type: 'button',
            text: 'MobileToolbar.Tab.Protect',
            iconCls: 'mobile__icon-tab-protect',
            handler: 'mobile-tab',
            canBeDisabled: false,
            params: {
                target: 'protectpanel'
            }
        }]
    };

    function hideSidebar(){
        var filemenu = $('[component-name=filemenu]').data('component');
        if(filemenu) {
            filemenu.deactive();
        }
    }
    function frameOpener(name) {
        var selector = '[component-name='+name+']';
        return function(){
            var frame = $(selector).data('component');
            if(frame) {
                frame.open();
            }
        }
    }
    var sidebar = {
        name: 'filemenu',
        type: 'togglepanel',
        cls: 'mobile__filemenu-panel',
        layout: 'flow',
        orientation: 'vertical',
        swipe: "left",
        sub: [{
            type: 'togglebutton',
            text: 'MobileToolbar.Sidebar.Back',
            cls: 'return-button button-inline',
            iconCls: 'mobile__icon-sidebar-back',
            toggle: 'filemenu'
        },{
            type: 'groups',
            groups: [{
                layout: 'flow',
                orientation: 'vertical',
                sub: [{
                    type: 'button',
                    text: 'MobileToolbar.Sidebar.Properties',
                    handler: frameOpener('file-infomation-frame'),
                    ga: {ct: 'File', ac: 'Properties'},
                    events: {
                        beforehandle: hideSidebar
                    }
                }, {
                    type: 'button',
                    text: 'MobileToolbar.Sidebar.Open',
                    canBeDisabled: false,
                    handler: frameOpener('open-file-frame'),
                    ga: {ct: 'File', ac: 'Open'},
                    events: {
                        beforehandle: hideSidebar
                    }
                }, {
                    type: 'button',
                    text: 'MobileToolbar.Sidebar.Save',
                    handler: 'exportToDisk',
                    ga: {ct: 'File', ac: 'Download'},
                    permissions: ['download'],
                    events: {
                        beforehandle: hideSidebar
                    }
                }, {
                    type: 'button',
                    text: 'MobileToolbar.Sidebar.Print',
                    permissions: ['print'],
                    handler: function(){
                        hideSidebar();
                        WebPDF.ViewerInstance.print();
                    },
                    ga: {ct: 'File', ac: 'Print'}
                }]
            }, {
                layout: 'flow',
                orientation: 'vertical',
                sub: [{
                    type: 'button',
                    text: 'MobileToolbar.Sidebar.TrustManager',
                    handler: function() {
                        WebPDF.JSEngine.showTrustManager();
                    },
                    ga: {ct: 'File', ac: 'Trust Manager'},
                    events: {
                        beforehandle: hideSidebar
                    }
                }]
            }]
        }]
    };

    var gotopageToolbar = {
        type: 'panel',
        name: 'gotopagetoolbar',
        cls: 'mobile__gotopage-toolbar mobile__top-toggle-toolbar',
        sub:[{
            type: 'button',
            cls: 'mobile__gotopage-toolbar-cancel',
            handler: 'mobilegotopage',
            action:'cancel',
            text: 'MobileToolbar.GotoPage.Cancel'
        },{
            type: 'input',
            attrs: {
                type: 'number'
            },
            clearable: true,
            name: 'gotopageinput',
            cls: 'mobile__gotopage-toolbar-input',
            handler: 'mobilegotopage',
            action:'goto',
        },{
            type: 'button',
            cls: 'mobile__gotopage-toolbar-ok',
            handler: 'mobilegotopage',
            action:'goto',
            text: 'MobileToolbar.GotoPage.Go'
        }]
    };

    var searchToolbar = {
        type: 'panel',
        cls: 'mobile__search-panel',
        name: 'searchtoolbar',
        sub: [{
            type:'panel',
            cls:'mobile__search-input-panel',
            sub:[{
                type: 'input',
                clearable: true,
                /*
                *^modifed by zhangjie
                *jira:WEBPDF-8068
                *2018/5/29
                *新增配置：添加点击clear图标的回调
                */
                clearCallback:function(){
                    $("#mobileSearchNotFound").hide();
                },
                /*$modifed by zhangjie*/
                name: 'mobile-quick-search-input',
                placeholder: 'MobileToolbar.Search.Placeholder',
                iconCls: 'mobile__icon-quick-search',
                handler: 'mobile-quick-search',
                action: 'search',
                attrs: {
                    type: 'search'
                }
            },{
                type:'popup',
                cls:'mobile__search-not-found',
                text:"[html]Search.NoFound1",
                attrs:{
                    id:"mobileSearchNotFound"
                }
            }]
        }, {
            type: 'button',
            text: 'MobileToolbar.Search.Cancel',
            handler: 'mobile-quick-search',
            action: 'cancel'
        }
        ]
    };

    var fileinfoFrame = {
        type: 'mobileframe',
        title: 'File information',
        name: 'file-infomation-frame',
        sub: [{
            type: 'mobilepropslist',
            properties: [{
                label: 'DocProperties.FilenName',
                value: function(){
                    return WebPDF.ViewerInstance.getFileName();
                }
            }, {
                label: 'MobileToolbar.PropertiesLabel.Path',
                value: function(){
                    return WebPDF.ViewerInstance.getFileUrl();
                }
            }, {
                label: 'MobileToolbar.PropertiesLabel.Size',
                value: function(){
                    var size = WebPDF.ViewerInstance.getFileSize();
                    var KB = 1024;
                    var MB = KB * 1024;
                    var GB = MB * 1024;
                    
                    if(size >= GB) {
                        return Math.round(size / GB * 100) / 100 + 'GB';
                    } else if(size >= MB) {
                        return Math.round(size / MB * 100) / 100 + 'MB';
                    } else if(size >= KB) {
                        return Math.round(size / KB * 100) / 100 + 'KB';
                    } else {
                        return size + 'Bytes';
                    }
                }
            }, {
                label: 'DocProperties.Author',
                value: function(){
                    var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
                    return docProperties.getAuthor();
                }
            }, {
                label: 'DocProperties.Subject',
                value: function(){
                    var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
                    return docProperties.getSubject();
                }
            }, {
                label: 'DocProperties.CreateDate',
                value: function(){
                    var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
                    return docProperties.getCreationDate();
                }
            }, {
                label: 'DocProperties.ModifyDate',
                value: function(){
                    var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
                    return docProperties.getModifyDate();
                }
            }]
        }]
    };

    var openfileFrame = {
        type: 'mobileframe',
        title: 'MobileToolbar.OpenFile.Title',
        name: 'open-file-frame',
        sub: [{
            type: 'panel',
            cls: 'mobile__open-file-panel',
            layout: 'flow',
            orientation: 'vertical',
            gap: 'lg',
            sub: [{
                type: 'fileSelector',
                accept: ['.pdf'],
                cls: 'button-inline mobile__file-btn',
                iconCls: 'mobile__icon-plus',
                text: 'MobileToolbar.OpenFile.OpenLocal',
                canBeDisabled: false,
                handler: 'openfile',
                events: {
                    afterhandle: function(){
                        var component = $('[component-name=open-file-frame]').data('component');
                        component.close();
                    }
                }
            }, {
                type: 'togglebutton',
                cls: 'button-inline mobile__file-btn',
                iconCls: 'mobile__icon-plus',
                canBeDisabled: false,
                text: 'MobileToolbar.OpenFile.OpenURL',
                toggle: 'open-file-file-url-input-panel'
            }, {
                type: 'togglepanel',
                name: 'open-file-file-url-input-panel',
                hideOnFocusOut: false,
                layout: 'flow',
                gap: 'lg',
                orientation:'vertical',
                sub: [{
                    type: 'template',
                    template: '<textarea class="mobile__open-file-textarea" data-i18n="[placeholder]MobileToolbar.OpenFile.URLPlaceholder" name="open-file-url">'
                }, {
                    type: 'button',
                    cls: 'mobile__open-file-url-btn',
                    /*
                    *^modifed by zhangjie
                    *jira:WEBPDF-7948
                    *2018/5/29
                    *没有这个配置的话，文档加载失败时，会把所有按钮都设置为disabled
                    */
                    canBeDisabled: false,
                    /*$modifed by zhangjie*/
                    text: "MobileToolbar.OpenFile.OpenURLButton",
                    handler: function(){
                        var url = $('[name=open-file-url]').val();
                        WebPDF.ViewerInstance.openFileByUri({
                            url: url,
                            fileId: url
                        });
                        var component = $('[component-name=open-file-frame]').data('component');
                        component.close();
                    }
                }]
            }]
        }] 
    };

    var viewToolbar = {
        type: 'groups',
        name: 'viewpanel',
        groups: [{
            layout: 'flow',
            orientation: 'horizontal',
            gap: 'md',
            cls: 'mobile__viewpanel-pageview-group',
            sub: [{
                type: 'button',
                // cls: 'fwr-rb-leftrotate',
                iconCls: 'mobile__icon-view-rotate-left',
                handler: 'rotate',
                ga: {ct: 'View', ac: 'Rotate Left'},
                params: {
                    // value: WebPDF.ROTATE_LEFT
                    value: 'left'
                }
            }, {
                type: 'button',
                // cls: 'fwr-rb-rightrotate',
                iconCls: 'mobile__icon-view-rotate-right',
                handler: 'rotate',
                ga: {ct: 'View', ac: 'Rotate Right'},
                params: {
                    // value: WebPDF.ROTATE_RIGHT
                    value: 'right'
                }
            }, {
                type: 'button',
                // cls: 'fwr-rb-singlepage',
                disabled: true,
                iconCls: 'mobile__icon-view-single-page',
                handler: 'showMode',
                ga: {ct: 'View', ac: 'Single Page'},
                params: {
                    // mode: WebPDF.PDFView.RD_BRMODE_SINGLE_PAGE
                    mode: 2
                }
            }, {
                type: 'button',
                // cls: 'fwr-rb-continuouspages',
                iconCls: 'mobile__icon-view-continuous-page',
                handler: 'showMode',
                ga: {ct: 'View', ac: 'Continuous Page'},
                params: {
                    // mode: WebPDF.PDFView.RD_BRMODE_CONTINUOUS
                    mode: 0
                }
            }, {
                type: 'button',
                iconCls: 'mobile__icon-view-fullscreen',
                handler: 'fullscreen',
                ga: {ct: 'View', ac: 'Full Screen'},
            }]
        }, {
            sub: [{
                type: 'mobilegotopage',
                handler: 'mobilegotopage',
                ga: {ct: 'View', ac: 'Goto Page'},
                action: 'showpanel'
            }]
        }],
    };

    var commentToolbar = {
        type: 'panel',
        name: 'commentpanel',
        sub: [{
            type: 'groups',
            groups: [{
                layout: 'flow',
                gap: 'md',
                sub: [{
                    type: 'dropdown',
                    inline: true,
                    syncIcon: true,
                    handler: 'noop',
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    selectOnDropdown: true,
                    buttons: [{
                        extend: 'highlight',
                        cls: '',
                        iconCls: 'mobile__icon-comment-highlight'
                    }, {
                        extend: 'strikeOut',
                        cls: '',
                        text: "MobileToolbar.Comment.StrikeOut",
                        iconCls: 'mobile__icon-comment-strikeout'
                    }, {
                        extend: 'underline',
                        cls: '',
                        text: "MobileToolbar.Comment.Underline",
                        iconCls: 'mobile__icon-comment-underline'
                    }, {
                        extend: 'squiggly',
                        cls: '',
                        text: "MobileToolbar.Comment.Squiggly",
                        iconCls: 'mobile__icon-comment-squiggly'
                    }, {
                        extend: 'replace',
                        cls: '',
                        text: "MobileToolbar.Comment.Replace",
                        iconCls: 'mobile__icon-comment-replace'
                    }, {
                        extend: 'caret',
                        cls: '',
                        text: "MobileToolbar.Comment.Caret",
                        iconCls: 'mobile__icon-comment-caret'
                    }],
                    permissions: ['annot', 'docannot']
                }, {
                    type: 'dropdown',
                    handler: 'noop',
                    inline: true,
                    syncIcon: true,
                    selectOnDropdown: true,
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    buttons: [{
                        extend: 'rectangle',
                        text: 'MobileToolbar.Comment.Rectangle',
                        iconCls: 'mobile__icon-comment-rectangle'
                    }, {
                        extend: 'polyline',
                        text: 'MobileToolbar.Comment.Polyline',
                        iconCls: 'mobile__icon-comment-polyline'
                    }, {
                        extend: 'cloud',
                        text: 'MobileToolbar.Comment.Cloud',
                        iconCls: 'mobile__icon-comment-cloud'
                    }, {
                        extend: 'circle',
                        text: 'MobileToolbar.Comment.Circle',
                        iconCls: 'mobile__icon-comment-circle'
                    }, {
                        extend: 'arrow',
                        text: 'MobileToolbar.Comment.Arrow',
                        iconCls: 'mobile__icon-comment-arrow'
                    }, {
                        extend: 'polygon',
                        text: 'MobileToolbar.Comment.Polygon',
                        iconCls: 'mobile__icon-comment-polygon'
                    }, {
                        extend: 'line',
                        text: 'MobileToolbar.Comment.Line',
                        iconCls: 'mobile__icon-comment-line'
                    }, {
                        extend: 'highlightarea',
                        iconCls: 'mobile__icon-comment-highlightarea'
                    }],
                    permissions: ['annot', 'docannot']
                }, {
                    type: 'dropdown',
                    handler: 'noop',
                    inline: true,
                    syncIcon: true,
                    selectOnDropdown: true,
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    buttons: [{
                        extend: 'typewriter',
                        cls: '',
                        iconCls: 'mobile__icon-comment-typewriter'
                    }, {
                        extend: 'callout',
                        cls: '',
                        iconCls: 'mobile__icon-comment-callout'
                    }, {
                        extend: 'textbox',
                        cls: '',
                        iconCls: 'mobile__icon-comment-textbox'
                    }],
                    permissions: ['annot', 'docannot']
                }]
            }, {
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'pencil',
                    iconCls: 'mobile__icon-comment-pencil'
                },{
                    extend: 'note',
                    cls: '',
                    iconCls: 'mobile__icon-comment-note'
                },{
                    extend: 'stamp',
                    iconCls: 'mobile__icon-comment-stamp',
                    events: {
                        beforehandle: function() {
                            $('.fwr-rb-toolbar-dropdown').hide();
                        }
                    }
                },{
                    extend: 'distance',
                    iconCls: 'mobile__icon-comment-distance'
                }]
            },{
                layout: 'flow',
                gap: 'md',
                sub: [{
                    type: 'dropdown',
                    inline: true,
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    iconCls: 'mobile__icon-comment-show-hide',
                    text: 'PCLng.ToolBar.Select',
                    handler: 'noop',
                    /*
                    *^modifed by zhangjie
                    *jira:WEBPDF-8090
                    *2018/5/30
                    *点击其他按钮（隐藏/显示，导入导出）切换到Hand工具
                    */
                    events:{
                        beforeShow:function () {
                            WebPDF.ViewerInstance.setCurrentToolByName("Hand");
                        }
                    },
                    /*$modifed by zhangjie*/
                    buttons: [{
                        extend: 'hideAllComments',
                        iconCls: 'mobile__icon-comment-hide-all'
                    }, {
                        extend: 'showAllComments',
                        iconCls: 'mobile__icon-comment-show-all'
                    }]
                },{
                    type: 'dropdown',
                    inline: true,
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    text: 'PCLng.ToolBar.ImportFile.Import',
                    iconCls: 'mobile__icon-comment-import',
                    handler: 'noop',
                    /*
                   *^modifed by zhangjie
                   *jira:WEBPDF-8090
                   *2018/5/30
                   *点击其他按钮（隐藏/显示，导入导出）切换到Hand工具
                   */
                    events:{
                        beforeShow:function () {
                            WebPDF.ViewerInstance.setCurrentToolByName("Hand");
                        }
                    },
                    /*$modifed by zhangjie*/
                    buttons: [{
                        extend: 'importFDF',
                        iconCls: 'mobile__icon-comment-import-fdf'
                    }, {
                        extend: 'importXFDF',
                        iconCls: 'mobile__icon-comment-import-xfdf'
                    }],
                    permissions: ['annot', 'docannot']
                }, {
                    type: 'dropdown',
                    inline: true,
                    style: 'entirety',
                    cls: 'mobile__dropdown',
                    text: 'PCLng.ToolBar.ExportFile.Export',
                    iconCls: 'mobile__icon-comment-export',
                    handler: 'noop',
                    /*
                   *^modifed by zhangjie
                   *jira:WEBPDF-8090
                   *2018/5/30
                   *点击其他按钮（隐藏/显示，导入导出）切换到Hand工具
                   */
                    events:{
                        beforeShow:function () {
                            WebPDF.ViewerInstance.setCurrentToolByName("Hand");
                        }
                    },
                    /*$modifed by zhangjie*/
                    buttons: [{
                        extend: 'exportFDF',
                        iconCls: 'mobile__icon-comment-export-fdf'
                    }, {
                        extend: 'exportXFDF',
                        iconCls: 'mobile__icon-comment-export-xfdf'
                    }]
                }]
            }]
        }]
    };

    var editToolbar = {
        type: 'panel',
        name: 'editpanel',
        sub: [{
            type: 'groups',
            groups: [{
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'edittext',
                    text: null,
                    iconCls: 'mobile__icon-edit-edittext'
                }, {
                    extend: 'addtext',
                    text: null,
                    iconCls: 'mobile__icon-edit-addtext'
                }]
            },{
                // font
                sub: [{
                    type: 'font',
                    fontFamilies: ['Arial', 'Calibri', 'Helvetica', 'Tahoma', 'Times New Roman', 'Verdana', '楷体', '宋体', '黑体', '微软雅黑'],
                    fontSizes: [8, 9, 10, 11, 12, 14, 16, 18, 20, 22, 24, 28, 36, 48, 72],
                    handler: 'font',
                    ga: {ct: 'Edit', ac: 'Formatting Fonts'}
                }]
            }, {
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'screen',
                    text: null,
                    iconCls: 'mobile__icon-screen'
                }]
            }]
        }]
    };

    var ppoToolbar = {
        type: 'panel',
        name: 'pageorganizepanel',
        layout: 'flow',
        gap: 'md',
        sub: [{
            type: 'button',
            tip: 'PCLng.ToolBar.Organize.RotateLeft',
            tipdesc: 'PCLng.ToolBar.Organize.RotateLeftTip',
            iconCls: 'mobile__icon-ppo-rotateleft',
            text: '[html]PCLng.ToolBar.Organize.RotateLeft',
            handler: 'ppo',
            ga: {ct: 'Organize', ac: 'Rotate Left'},
            params: {
                action: 'rotateLeft'
            },
            permissions: ['modifiable']
        }, {
            type: 'button',
            tip: 'PCLng.ToolBar.Organize.RotateRight',
            tipdesc: 'PCLng.ToolBar.Organize.RotateRightTip',
            iconCls: 'mobile__icon-ppo-rotateright',
            text: '[html]PCLng.ToolBar.Organize.RotateRight',
            handler: 'ppo',
            ga: {ct: 'Organize', ac: 'Rotate Right'},
            params: {
                action: 'rotateRight'
            },
            permissions: ['modifiable']
        }, {
            type: 'button',
            tip: 'PCLng.ToolBar.Organize.BlankPage',
            tipdesc: 'PCLng.ToolBar.Organize.BlankPageTip',
            iconCls: 'mobile__icon-ppo-blank',
            text: '[html]PCLng.ToolBar.Organize.BlankPage',
            handler: 'ppo',
            params: {
                action: 'blankPage'
            },
            permissions: ['modifiable']
        }, {
            type: 'button',
            tip: 'PCLng.ToolBar.Organize.SelectPage',
            tipdesc: 'PCLng.ToolBar.Organize.SelectPageTip',
            iconCls: 'mobile__icon-ppo-selectpage',
            text: '[html]PCLng.ToolBar.Organize.SelectPage',
            handler: 'ppo',
            ga: {ct: 'Organize', ac: 'Select Page'},
            params: {
                action: 'selectPage'
            },
            permissions: ['modifiable']
        }, {
            type: 'button',
            tip: 'PCLng.ToolBar.Organize.DeletePage',
            tipdesc: 'PCLng.ToolBar.Organize.DeletePageTip',
            iconCls: 'mobile__icon-ppo-deletepage',
            text: '[html]PCLng.ToolBar.Organize.DeletePage',
            handler: 'ppo',
            ga: {ct: 'Organize', ac: 'Delete Page'},
            params: {
                action: 'deletePage'
            },
            permissions: ['modifiable']
        }]
    };

    var protectToolbar = {
        type: 'panel',
        name: 'protectpanel',
        sub:[{
            type: 'groups',
            groups:[{
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'markRedaction',
                    iconCls: 'mobile__icon-mark-redaction'
                }, {
                    extend: 'applyRedaction',
                    iconCls: 'mobile__icon-apply-redaction'
                }]
            }, {
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'inksign',
                    iconCls: 'mobile__icon-inksign'
                }]
            }, {
                layout: 'flow',
                gap: 'md',
                sub: [{
                    extend: 'passwordProtect',
                    iconCls: 'mobile__icon-password-protect'
                }]
            }]
        }]
    };

    var config = {
        top: {
            type: 'panel',
            sub: [
                topToolbar,
                undoredoToolbar,
                pageOrganizeToolbar,
                viewTabs, 
                sidebar,
                gotopageToolbar,
                searchToolbar,
                fileinfoFrame,
                openfileFrame
            ]
        },
        bottom: {
            type: 'scrollpanel',
            cls: 'mobile__bottom-toolbar',
            appendTo: '#right',
            name: 'mobile-bottom-toolbar',
            sub: [
                viewToolbar,
                commentToolbar , 
                editToolbar,
                ppoToolbar,
                protectToolbar
            ]
        }
    };
    var config_1 = config.top;
    var config_2 = config.bottom;

    exports.default = config;
    exports.top = config_1;
    exports.bottom = config_2;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
